% Dynare example: Stochastic Solow growth model.
% By Anton Babkin. 18 mar 2016.

% endogenous variables
var k y a i c;

% exogenous variables
varexo e;

% parameters
parameters alpha delta s rho sigma;
alpha = 1/3;
delta = 0.1;
s = 0.2;
rho = 0.9;
sigma = 0.01;

% specify model equations
% note: variables are in logs!
model;
    exp(y) = exp(a) * exp(k(-1))^alpha;
    exp(i) = s * exp(y);
    exp(c) = (1-s) * exp(y);
    exp(k) = (1-delta) * exp(k(-1)) + exp(i);
    a = rho * a(-1) + e;
end;

% closed-form analytical solution for steady state
steady_state_model;
    k_ = (s / delta)^(1 / (1-alpha));
    y_ = k_^alpha;
    a = 0;
    i = log(s * y_);
    c = log((1-s) * y_);
    k = log(k_);
    y = log(y_);
end;

% specify exogenous shocks
shocks;
    var e = sigma^2;
end;

% compute steady state
steady;

% do the magic
stoch_simul(order=1, irf=20, periods=300);
